package Life;

use Seven qw/all/;

riot sub {
	print "You are inciting a..."
};

laughter sub {
	print "While the true innocent could laugh first"; 
};

greed sub {
	print "Because we are all greedy dictators that do not understand the world";
};

dishonesty sub {
	print "While one of your own slaves fights for all others";
};

innocent sub {
	print "All those who are not using theres as shields but are probably the police of there own slaves";
};	

accountability sub {
	print "Stand accountable for your crimes";
};

luck;
